.. _phononic-band_gaps_rigid:

phononic/band_gaps_rigid.py
===========================

**Description**


Acoustic band gaps in a strongly heterogeneous elastic body with a rigid
inclusion, detected using homogenization techniques.

A reference periodic cell contains three domains: the stiff matrix :math:`Y_m`
and the soft inclusion :math:`Y_c` enclosing the rigid heavy sub-inclusion
:math:`Y_r`.


.. image:: /../doc/images/gallery/phononic-band_gaps_rigid-band_gaps_rigid.png
.. image:: /../doc/images/gallery/phononic-band_gaps_rigid.png


:download:`source code </../sfepy/examples/phononic/band_gaps_rigid.py>`

.. literalinclude:: /../sfepy/examples/phononic/band_gaps_rigid.py

